from argparse import ArgumentParser


def arg_parser():
    parser = ArgumentParser(prog="nrql-simple")
    parser.add_argument("stmt", help="The NRQL statement.")
    parser.add_argument(
        "--region",
        "--r",
        default="US",
        help="Pass this flag to set your region (EU or US) By default the region is set to US.",
    )
    parser.add_argument("--env", "--e", help="Environment handler.")
    parser.add_argument(
        "--filename",
        "--f",
        default="events.csv",
        help="The output CSV filename. Default is events.csv",
    )
    parser.add_argument(
        "--csv",
        "--c",
        dest="output_csv",
        action="store_true",
        default=False,
        help="Pass this flag to output the Event data to CSV.",
    )
    parser.add_argument(
        "--verbose",
        "--v",
        dest="verbose",
        action="store_true",
        default=False,
        help="Pass this flag if you want the whole response.",
    )
    args = parser.parse_args()
    return args



import json

import pandas as pd
from pygments import highlight, lexers, formatters


def export_as_csv(data, filename):
    if not (
        "results" in data
        and "events" in data["results"][0]
        and len(data["results"][0]["events"]) > 0
    ):
        print(prettyjson(data))
        return
    data.pop("metadata", None)
    data.pop("performanceStats", None)
    df = pd.DataFrame(data["results"][0]["events"])
    df.to_csv(filename, index=False, header=True)
    print("Exported to csv: %s" % filename)


def prettyjson(req):
    formatted_json = json.dumps(req, sort_keys=True, indent=4)
    return highlight(
        str(formatted_json).encode("utf-8"),
        lexers.JsonLexer(),
        formatters.TerminalFormatter(),
    )



from .api import NRQL
from .utils import prettyjson, export_as_csv
from .args_parser import arg_parser


def main():
    nrql = NRQL()
    args = arg_parser()
    nrql.region = args.region
    nrql.verbose = args.verbose
    nrql.environment = args.env
    req = nrql.query(args.stmt)
    if args.output_csv:
        export_as_csv(req, args.filename)
    else:
        print(prettyjson(req))


if __name__ == "__main__":
    main()



import requests
import os
from .utils import export_as_csv
import colorful

INSIGHTS_URL = "https://insights-api.newrelic.com/v1/accounts/%s/query"
INSIGHTS_EU_REGION_URL = "https://insights-api.eu.newrelic.com/v1/accounts/%s/query"


class NRQL(object):
    def __init__(self, api_key=None, account_id=None):
        self.api_key = api_key
        self.account_id = account_id
        self._url = INSIGHTS_URL
        self._eu_url = INSIGHTS_EU_REGION_URL
        self._region = "US"
        self._verbose = False
        self._csv = False
        self._environment = None
        self._stmt = []
        self._filename = "events.csv"

    @property
    def api_key(self):
        return self._api_key

    @api_key.setter
    def api_key(self, api_key):
        self._api_key = api_key

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        self._account_id = account_id

    @property
    def region(self):
        return self._region

    @region.setter
    def region(self, region):
        self._region = region

    @property
    def filename(self):
        return self._filename

    @filename.setter
    def filename(self, filename):
        self._filename = filename

    @property
    def csv(self):
        return self._csv

    @csv.setter
    def csv(self, csv):
        self._csv = csv

    @property
    def verbose(self):
        return self._verbose

    @verbose.setter
    def verbose(self, verbose):
        self._verbose = verbose

    @property
    def environment(self):
        return self._environment

    @environment.setter
    def environment(self, environment):
        self._environment = environment

    @staticmethod
    def _print_messages(response):
        if "metadata" in response and "messages" in response["metadata"]:
            for message in response["metadata"]["messages"]:
                print(colorful.bold(message))

    def _multiple_account_handler(self):
        if self.environment is None:
            nr_api_key = os.environ.get("NR_API_KEY")
            nr_account_id = os.environ.get("NR_ACCOUNT_ID")
        else:
            nr_api_key = os.environ.get("NR_API_KEY_%s" % self.environment.upper())
            nr_account_id = os.environ.get(
                "NR_ACCOUNT_ID_%s" % self.environment.upper()
            )
            if not nr_account_id or not nr_api_key:
                print(colorful.bold("%s account environment variables not set." % self.environment))
        return nr_api_key, nr_account_id

    def _make_request(self, query_stmt):
        payload = {"nrql": query_stmt}
        req = requests.get(
            self._url % self.account_id,
            headers={"X-Query-Key": self.api_key},
            params=payload,
        )
        if self.verbose:
            print(colorful.bold("Request URL: %s" % req.url))
            print(colorful.bold("Status Code: %s" % req.status_code))
        response = req.json()
        self._print_messages(response)
        if not self.verbose:
            response.pop("metadata", None)
            response.pop("performanceStats", None)

        return response

    def query(self, stmt):
        nr_api_key, nr_account_id = self._multiple_account_handler()
        if not self.api_key or not self.account_id:
            if nr_api_key and nr_account_id:
                self._api_key = nr_api_key
                self._account_id = nr_account_id
            else:
                raise Exception("An api key and account id is required.")

        if not self.region == "US":
            self._url = self._eu_url

        resp = self._make_request(stmt)
        if self.csv:
            export_as_csv(resp, self.filename)
        else:
            return resp
